import React, { useEffect, useState } from 'react';

import { Header, PageWrapper, MenuButton } from '../../../../components';
import { NAVIGATION_PAGES } from '../../../../types';
import { Colors } from '../../../../theme';

import UserPenIcon from '../../../../../assets/icons/user-pen.svg';
import UserPlusIcon from '../../../../../assets/icons/user-plus.svg';
import BellIcon from '../../../../../assets/icons/bell.svg';
import MailIcon from '../../../../../assets/icons/mail.svg';
import FAQIcon from '../../../../../assets/icons/faq.svg';
import DocumentIcon from '../../../../../assets/icons/document.svg';
import ShieldIcon from '../../../../../assets/icons/shield.svg';
import ExitIcon from '../../../../../assets/icons/exit.svg';
import UserXMark from '../../../../../assets/icons/user-xmark.svg';

import type { MenuButtonType } from '../../../../types/components';
import { Switch, Text, View } from 'react-native';
import { getOnlineStatus, storage } from 'src/storage';
import { CommonActions } from '@react-navigation/native';

const buttons: MenuButtonType[] = [
  {
    label: 'Edit Profile',
    icon: <UserPenIcon fill={Colors.DARK_BLUE} width={20} height={20} />,
    buttonFn: (navigation) => {
      navigation.navigate(NAVIGATION_PAGES.EDIT_PERSONAL_INFO);
    }
  },
  {
    label: 'Invite a Friend',
    icon: <UserPlusIcon fill={Colors.DARK_BLUE} width={20} height={20} />
  },
  {
    label: 'Notification',
    icon: <BellIcon fill={Colors.DARK_BLUE} width={20} height={20} />
  },
  {
    label: 'Contact Us',
    icon: <MailIcon fill={Colors.DARK_BLUE} width={20} height={20} />
  },
  {
    label: 'FAQs',
    icon: <FAQIcon fill={Colors.DARK_BLUE} width={20} height={20} />
  },
  {
    label: 'Terms & Conditions',
    icon: <DocumentIcon fill={Colors.DARK_BLUE} width={20} height={20} />
  },
  {
    label: 'Privacy Notice',
    icon: <ShieldIcon fill={Colors.DARK_BLUE} width={20} height={20} />
  },
  {
    label: 'Logout',
    icon: <ExitIcon fill={Colors.RED} width={20} height={20} />,
    red: true,
    buttonFn: (navigation) => {
      storage.remove('token');
      storage.remove('uid');

      navigation.dispatch(
        CommonActions.reset({
          index: 1,
          routes: [{ name: NAVIGATION_PAGES.WELCOME }]
        })
      );
    }
  },
  {
    label: 'Delete account',
    icon: <UserXMark fill={Colors.RED} width={20} height={20} />,
    red: true
  }
];

const Settings = () => {
  const [isEnabled, setIsEnabled] = useState(Boolean(getOnlineStatus()));

  useEffect(() => {
    storage.set('online', isEnabled);
  }, [isEnabled]);

  const toggleSwitch = () => {
    setIsEnabled(!isEnabled);
  };

  return (
    <PageWrapper>
      <Header label={'Settings'} />
      {buttons.map((button) => (
        <MenuButton
          label={button.label}
          icon={button.icon}
          red={button.red}
          buttonFn={button.buttonFn}
        />
      ))}
      <View
        style={{
          display: 'flex',
          flexDirection: 'row',
          justifyContent: 'space-between',
          marginTop: 20
        }}
      >
        <Text style={{ color: Colors.DARK_BLUE, fontSize: 16, fontWeight: 'bold' }}>
          Offline mode
        </Text>
        <Switch
          trackColor={{ false: Colors.LIGHT_GRAY, true: Colors.RED }}
          thumbColor={Colors.WHITE}
          onValueChange={toggleSwitch}
          value={!isEnabled}
        />
      </View>
    </PageWrapper>
  );
};

export default Settings;
