import { Text, TouchableOpacity, View } from 'react-native';
import { styles } from './styles';
import { Colors } from 'src/theme';

export const CustomButton = ({
  onPress,
  title,
  icon,
  isActive,
  disabled
}: {
  onPress: () => void;
  title?: string;
  icon?: JSX.Element;
  isActive?: boolean;
  disabled?: boolean;
}) => (
  <TouchableOpacity
    style={[
      styles.buttonStyle,
      isActive ? styles.buttonActive : styles.buttonInactive,
      { flex: icon && title ? 0.7 : 1, opacity: disabled ? 0.5 : 1 }
    ]}
    onPress={onPress}
    disabled={disabled}
  >
    {icon && (
      <View style={title ? { marginRight: 5 } : { paddingHorizontal: 16, paddingVertical: 8 }}>
        {icon}
      </View>
    )}
    {title && <Text style={[styles.buttonText, isActive && { color: Colors.WHITE }]}>{title}</Text>}
  </TouchableOpacity>
);
